/* default-contact.c generated by valac 0.21.1.1-0d6f, the Vala compiler
 * generated from default-contact.vala, do not modify */

/*
 * Copyright (C) 2011 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Raul Gutierrez Segales <raul.gutierrez.segales@collabora.co.uk>
 *
 */

#include <glib.h>
#include <glib-object.h>
#include <tracker-test.h>
#include <stdlib.h>
#include <string.h>
#include <folks/folks.h>
#include <folks-test.h>
#include <gee.h>
#include <folks/folks-tracker.h>
#include <gio/gio.h>


#define TYPE_DEFAULT_CONTACT_TESTS (default_contact_tests_get_type ())
#define DEFAULT_CONTACT_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DEFAULT_CONTACT_TESTS, DefaultContactTests))
#define DEFAULT_CONTACT_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DEFAULT_CONTACT_TESTS, DefaultContactTestsClass))
#define IS_DEFAULT_CONTACT_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DEFAULT_CONTACT_TESTS))
#define IS_DEFAULT_CONTACT_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DEFAULT_CONTACT_TESTS))
#define DEFAULT_CONTACT_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DEFAULT_CONTACT_TESTS, DefaultContactTestsClass))

typedef struct _DefaultContactTests DefaultContactTests;
typedef struct _DefaultContactTestsClass DefaultContactTestsClass;
typedef struct _DefaultContactTestsPrivate DefaultContactTestsPrivate;
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _DefaultContactTestsTestDefaultContactAsyncData DefaultContactTestsTestDefaultContactAsyncData;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _DefaultContactTests {
	TrackerTestTestCase parent_instance;
	DefaultContactTestsPrivate * priv;
};

struct _DefaultContactTestsClass {
	TrackerTestTestCaseClass parent_class;
};

struct _DefaultContactTestsPrivate {
	gboolean _found_default_user;
	gboolean _found_not_user;
	gboolean _found_unknown_user;
	GMainLoop* _main_loop;
	gchar* _fullname_persona;
	FolksIndividualAggregator* _aggregator;
};

struct _DefaultContactTestsTestDefaultContactAsyncData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	DefaultContactTests* self;
	FolksBackendStore* store;
	FolksBackendStore* _tmp0_;
	FolksIndividualAggregator* _tmp1_;
	FolksIndividualAggregator* _tmp2_;
	FolksIndividualAggregator* _tmp3_;
	GError* e;
	GError* _tmp4_;
	const gchar* _tmp5_;
	GError * _inner_error_;
};


static gpointer default_contact_tests_parent_class = NULL;

GType default_contact_tests_get_type (void) G_GNUC_CONST;
#define DEFAULT_CONTACT_TESTS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_DEFAULT_CONTACT_TESTS, DefaultContactTestsPrivate))
enum  {
	DEFAULT_CONTACT_TESTS_DUMMY_PROPERTY
};
DefaultContactTests* default_contact_tests_new (void);
DefaultContactTests* default_contact_tests_construct (GType object_type);
void default_contact_tests_test_default_contact (DefaultContactTests* self);
static void _default_contact_tests_test_default_contact_folks_test_case_test_method (gpointer self);
static void _default_contact_tests_test_default_contact_async (DefaultContactTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _default_contact_tests_test_default_contact_finish (DefaultContactTests* self, GAsyncResult* _res_);
static void _default_contact_tests_test_default_contact_async_data_free (gpointer _data);
static gboolean _default_contact_tests_test_default_contact_async_co (DefaultContactTestsTestDefaultContactAsyncData* _data_);
static void _default_contact_tests_test_default_contact_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _default_contact_tests_individuals_changed_cb (DefaultContactTests* self, GeeMultiMap* changes);
static void __default_contact_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void default_contact_tests_finalize (GObject* obj);
gint _vala_main (gchar** args, int args_length1);


static void _default_contact_tests_test_default_contact_folks_test_case_test_method (gpointer self) {
#line 38 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	default_contact_tests_test_default_contact (self);
#line 115 "default-contact.c"
}


DefaultContactTests* default_contact_tests_construct (GType object_type) {
	DefaultContactTests * self = NULL;
#line 36 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	self = (DefaultContactTests*) tracker_test_test_case_construct (object_type, "DefaultContactTests");
#line 38 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "test default contact", _default_contact_tests_test_default_contact_folks_test_case_test_method, self);
#line 34 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	return self;
#line 127 "default-contact.c"
}


DefaultContactTests* default_contact_tests_new (void) {
#line 34 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	return default_contact_tests_construct (TYPE_DEFAULT_CONTACT_TESTS);
#line 134 "default-contact.c"
}


void default_contact_tests_test_default_contact (DefaultContactTests* self) {
	GMainLoop* _tmp0_ = NULL;
	GeeHashMap* c1 = NULL;
	GeeHashMap* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	TrackerTestBackend* _tmp4_ = NULL;
	TrackerTestBackend* _tmp5_ = NULL;
	GMainLoop* _tmp6_ = NULL;
	gboolean _tmp7_ = FALSE;
	gboolean _tmp8_ = FALSE;
	gboolean _tmp9_ = FALSE;
#line 41 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	g_return_if_fail (self != NULL);
#line 43 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 43 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 43 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	self->priv->_main_loop = _tmp0_;
#line 44 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	_tmp1_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 44 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	c1 = _tmp1_;
#line 45 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	_tmp2_ = g_strdup ("persona #1");
#line 45 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	_g_free0 (self->priv->_fullname_persona);
#line 45 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	self->priv->_fullname_persona = _tmp2_;
#line 47 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	_tmp3_ = self->priv->_fullname_persona;
#line 47 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c1, TRF_ONTOLOGY_DEFS_NCO_FULLNAME, _tmp3_);
#line 48 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	_tmp4_ = ((TrackerTestTestCase*) self)->tracker_backend;
#line 48 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	tracker_test_backend_add_contact (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, TRACKER_TEST_TYPE_BACKEND, TrackerTestBackend), c1);
#line 50 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	_tmp5_ = ((TrackerTestTestCase*) self)->tracker_backend;
#line 50 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	tracker_test_backend_set_up (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, TRACKER_TEST_TYPE_BACKEND, TrackerTestBackend));
#line 52 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	self->priv->_found_default_user = FALSE;
#line 53 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	self->priv->_found_not_user = FALSE;
#line 54 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	self->priv->_found_unknown_user = FALSE;
#line 56 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	_default_contact_tests_test_default_contact_async (self, NULL, NULL);
#line 58 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	_tmp6_ = self->priv->_main_loop;
#line 58 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	folks_test_utils_loop_run_with_timeout (_tmp6_, 5);
#line 60 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	_tmp7_ = self->priv->_found_default_user;
#line 60 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	_vala_assert (_tmp7_ == TRUE, "this._found_default_user == true");
#line 61 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	_tmp8_ = self->priv->_found_not_user;
#line 61 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	_vala_assert (_tmp8_ == TRUE, "this._found_not_user == true");
#line 62 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	_tmp9_ = self->priv->_found_unknown_user;
#line 62 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	_vala_assert (_tmp9_ == FALSE, "this._found_unknown_user == false");
#line 41 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	_g_object_unref0 (c1);
#line 206 "default-contact.c"
}


static void _default_contact_tests_test_default_contact_async_data_free (gpointer _data) {
	DefaultContactTestsTestDefaultContactAsyncData* _data_;
	_data_ = _data;
#line 26 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	_g_object_unref0 (_data_->self);
#line 26 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	g_slice_free (DefaultContactTestsTestDefaultContactAsyncData, _data_);
#line 217 "default-contact.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 26 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	return self ? g_object_ref (self) : NULL;
#line 224 "default-contact.c"
}


static void _default_contact_tests_test_default_contact_async (DefaultContactTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	DefaultContactTestsTestDefaultContactAsyncData* _data_;
	DefaultContactTests* _tmp0_ = NULL;
#line 26 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	_data_ = g_slice_new0 (DefaultContactTestsTestDefaultContactAsyncData);
#line 26 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _default_contact_tests_test_default_contact_async);
#line 26 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _default_contact_tests_test_default_contact_async_data_free);
#line 26 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 26 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	_data_->self = _tmp0_;
#line 26 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	_default_contact_tests_test_default_contact_async_co (_data_);
#line 243 "default-contact.c"
}


static void _default_contact_tests_test_default_contact_finish (DefaultContactTests* self, GAsyncResult* _res_) {
	DefaultContactTestsTestDefaultContactAsyncData* _data_;
#line 26 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 251 "default-contact.c"
}


static void _default_contact_tests_test_default_contact_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	DefaultContactTestsTestDefaultContactAsyncData* _data_;
#line 68 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	_data_ = _user_data_;
#line 68 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	_data_->_source_object_ = source_object;
#line 68 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	_data_->_res_ = _res_;
#line 68 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	_default_contact_tests_test_default_contact_async_co (_data_);
#line 265 "default-contact.c"
}


static void __default_contact_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 70 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	_default_contact_tests_individuals_changed_cb (self, changes);
#line 272 "default-contact.c"
}


static gboolean _default_contact_tests_test_default_contact_async_co (DefaultContactTestsTestDefaultContactAsyncData* _data_) {
#line 65 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	switch (_data_->_state_) {
#line 65 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
		case 0:
#line 281 "default-contact.c"
		goto _state_0;
#line 65 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
		case 1:
#line 285 "default-contact.c"
		goto _state_1;
#line 65 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
		case 2:
#line 289 "default-contact.c"
		goto _state_2;
		default:
#line 65 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
		g_assert_not_reached ();
#line 294 "default-contact.c"
	}
	_state_0:
#line 67 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	_data_->_tmp0_ = NULL;
#line 67 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	_data_->_tmp0_ = folks_backend_store_dup ();
#line 67 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	_data_->store = _data_->_tmp0_;
#line 68 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	_data_->_state_ = 1;
#line 68 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	folks_backend_store_prepare (_data_->store, _default_contact_tests_test_default_contact_async_ready, _data_);
#line 68 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	return FALSE;
#line 309 "default-contact.c"
	_state_1:
#line 68 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	folks_backend_store_prepare_finish (_data_->store, _data_->_res_);
#line 69 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	_data_->_tmp1_ = NULL;
#line 69 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	_data_->_tmp1_ = folks_individual_aggregator_dup ();
#line 69 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	_g_object_unref0 (_data_->self->priv->_aggregator);
#line 69 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	_data_->self->priv->_aggregator = _data_->_tmp1_;
#line 70 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	_data_->_tmp2_ = NULL;
#line 70 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	_data_->_tmp2_ = _data_->self->priv->_aggregator;
#line 70 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	g_signal_connect_object (_data_->_tmp2_, "individuals-changed-detailed", (GCallback) __default_contact_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed, _data_->self, 0);
#line 327 "default-contact.c"
	{
#line 74 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
		_data_->_tmp3_ = NULL;
#line 74 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
		_data_->_tmp3_ = _data_->self->priv->_aggregator;
#line 74 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
		_data_->_state_ = 2;
#line 74 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
		folks_individual_aggregator_prepare (_data_->_tmp3_, _default_contact_tests_test_default_contact_async_ready, _data_);
#line 74 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
		return FALSE;
#line 339 "default-contact.c"
		_state_2:
#line 74 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
		folks_individual_aggregator_prepare_finish (_data_->_tmp3_, _data_->_res_, &_data_->_inner_error_);
#line 74 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
		if (_data_->_inner_error_ != NULL) {
#line 345 "default-contact.c"
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
#line 72 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
		_data_->e = _data_->_inner_error_;
#line 72 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
		_data_->_inner_error_ = NULL;
#line 78 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
		_data_->_tmp4_ = NULL;
#line 78 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
		_data_->_tmp4_ = _data_->e;
#line 78 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
		_data_->_tmp5_ = NULL;
#line 78 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
		_data_->_tmp5_ = _data_->_tmp4_->message;
#line 78 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
		g_warning ("default-contact.vala:78: Error when calling prepare: %s\n", _data_->_tmp5_);
#line 72 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
		_g_error_free0 (_data_->e);
#line 368 "default-contact.c"
	}
	__finally0:
#line 72 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	if (_data_->_inner_error_ != NULL) {
#line 72 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
		_g_object_unref0 (_data_->store);
#line 72 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 72 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
		g_clear_error (&_data_->_inner_error_);
#line 72 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
		return FALSE;
#line 381 "default-contact.c"
	}
#line 65 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	_g_object_unref0 (_data_->store);
#line 65 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	if (_data_->_state_ == 0) {
#line 65 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 389 "default-contact.c"
	} else {
#line 65 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 393 "default-contact.c"
	}
#line 65 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	g_object_unref (_data_->_async_result);
#line 65 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	return FALSE;
#line 399 "default-contact.c"
}


static void _default_contact_tests_individuals_changed_cb (DefaultContactTests* self, GeeMultiMap* changes) {
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeCollection* _tmp1_ = NULL;
	GeeSet* removed = NULL;
	GeeMultiMap* _tmp2_ = NULL;
	GeeSet* _tmp3_ = NULL;
	gboolean _tmp28_ = FALSE;
	gboolean _tmp29_ = FALSE;
	gboolean _tmp31_ = FALSE;
	GeeSet* _tmp33_ = NULL;
	gint _tmp34_ = 0;
	gint _tmp35_ = 0;
#line 82 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	g_return_if_fail (self != NULL);
#line 82 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	g_return_if_fail (changes != NULL);
#line 85 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	_tmp0_ = changes;
#line 85 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 85 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	added = _tmp1_;
#line 86 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	_tmp2_ = changes;
#line 86 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	_tmp3_ = gee_multi_map_get_keys (_tmp2_);
#line 86 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	removed = _tmp3_;
#line 432 "default-contact.c"
	{
		GeeIterator* _i_it = NULL;
		GeeCollection* _tmp4_ = NULL;
		GeeIterator* _tmp5_ = NULL;
#line 88 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
		_tmp4_ = added;
#line 88 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
		_tmp5_ = gee_iterable_iterator ((GeeIterable*) _tmp4_);
#line 88 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
		_i_it = _tmp5_;
#line 88 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
		while (TRUE) {
#line 445 "default-contact.c"
			GeeIterator* _tmp6_ = NULL;
			gboolean _tmp7_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp8_ = NULL;
			gpointer _tmp9_ = NULL;
			FolksIndividual* _tmp10_ = NULL;
			gchar* full_name = NULL;
			FolksIndividual* _tmp11_ = NULL;
			const gchar* _tmp12_ = NULL;
			const gchar* _tmp13_ = NULL;
			gchar* _tmp14_ = NULL;
			gboolean _tmp15_ = FALSE;
			gboolean _tmp16_ = FALSE;
			const gchar* _tmp17_ = NULL;
			gboolean _tmp20_ = FALSE;
			gboolean _tmp24_ = FALSE;
#line 88 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
			_tmp6_ = _i_it;
#line 88 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
			_tmp7_ = gee_iterator_next (_tmp6_);
#line 88 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
			if (!_tmp7_) {
#line 88 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
				break;
#line 470 "default-contact.c"
			}
#line 88 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
			_tmp8_ = _i_it;
#line 88 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 88 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
			i = (FolksIndividual*) _tmp9_;
#line 90 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
			_tmp10_ = i;
#line 90 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
			_vala_assert (_tmp10_ != NULL, "i != null");
#line 92 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
			_tmp11_ = i;
#line 92 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
			_tmp12_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp11_);
#line 92 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
			_tmp13_ = _tmp12_;
#line 92 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
			_tmp14_ = g_strdup (_tmp13_);
#line 92 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
			full_name = _tmp14_;
#line 93 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
			_tmp17_ = full_name;
#line 93 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
			if (_tmp17_ != NULL) {
#line 496 "default-contact.c"
				const gchar* _tmp18_ = NULL;
				const gchar* _tmp19_ = NULL;
#line 93 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
				_tmp18_ = full_name;
#line 93 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
				_tmp19_ = self->priv->_fullname_persona;
#line 93 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
				_tmp16_ = g_strcmp0 (_tmp18_, _tmp19_) == 0;
#line 505 "default-contact.c"
			} else {
#line 93 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
				_tmp16_ = FALSE;
#line 509 "default-contact.c"
			}
#line 93 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
			_tmp20_ = _tmp16_;
#line 93 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
			if (_tmp20_) {
#line 515 "default-contact.c"
				FolksIndividual* _tmp21_ = NULL;
				gboolean _tmp22_ = FALSE;
				gboolean _tmp23_ = FALSE;
#line 94 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
				_tmp21_ = i;
#line 94 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
				_tmp22_ = folks_individual_get_is_user (_tmp21_);
#line 94 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
				_tmp23_ = _tmp22_;
#line 94 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
				_tmp15_ = _tmp23_ == FALSE;
#line 527 "default-contact.c"
			} else {
#line 93 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
				_tmp15_ = FALSE;
#line 531 "default-contact.c"
			}
#line 93 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
			_tmp24_ = _tmp15_;
#line 93 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
			if (_tmp24_) {
#line 96 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
				self->priv->_found_not_user = TRUE;
#line 539 "default-contact.c"
			} else {
				FolksIndividual* _tmp25_ = NULL;
				gboolean _tmp26_ = FALSE;
				gboolean _tmp27_ = FALSE;
#line 98 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
				_tmp25_ = i;
#line 98 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
				_tmp26_ = folks_individual_get_is_user (_tmp25_);
#line 98 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
				_tmp27_ = _tmp26_;
#line 98 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
				if (_tmp27_ == TRUE) {
#line 100 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
					self->priv->_found_default_user = TRUE;
#line 554 "default-contact.c"
				} else {
#line 104 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
					self->priv->_found_unknown_user = TRUE;
#line 558 "default-contact.c"
				}
			}
#line 88 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
			_g_free0 (full_name);
#line 88 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
			_g_object_unref0 (i);
#line 565 "default-contact.c"
		}
#line 88 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
		_g_object_unref0 (_i_it);
#line 569 "default-contact.c"
	}
#line 108 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	_tmp29_ = self->priv->_found_not_user;
#line 108 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	if (_tmp29_) {
#line 575 "default-contact.c"
		gboolean _tmp30_ = FALSE;
#line 109 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
		_tmp30_ = self->priv->_found_default_user;
#line 109 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
		_tmp28_ = _tmp30_;
#line 581 "default-contact.c"
	} else {
#line 108 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
		_tmp28_ = FALSE;
#line 585 "default-contact.c"
	}
#line 108 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	_tmp31_ = _tmp28_;
#line 108 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	if (_tmp31_) {
#line 591 "default-contact.c"
		GMainLoop* _tmp32_ = NULL;
#line 110 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
		_tmp32_ = self->priv->_main_loop;
#line 110 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
		g_main_loop_quit (_tmp32_);
#line 597 "default-contact.c"
	}
#line 112 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	_tmp33_ = removed;
#line 112 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	_tmp34_ = gee_collection_get_size ((GeeCollection*) _tmp33_);
#line 112 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	_tmp35_ = _tmp34_;
#line 112 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	_vala_assert (_tmp35_ == 1, "removed.size == 1");
#line 607 "default-contact.c"
	{
		GeeIterator* _i_it = NULL;
		GeeSet* _tmp36_ = NULL;
		GeeIterator* _tmp37_ = NULL;
#line 114 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
		_tmp36_ = removed;
#line 114 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
		_tmp37_ = gee_iterable_iterator ((GeeIterable*) _tmp36_);
#line 114 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
		_i_it = _tmp37_;
#line 114 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
		while (TRUE) {
#line 620 "default-contact.c"
			GeeIterator* _tmp38_ = NULL;
			gboolean _tmp39_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp40_ = NULL;
			gpointer _tmp41_ = NULL;
			FolksIndividual* _tmp42_ = NULL;
#line 114 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
			_tmp38_ = _i_it;
#line 114 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
			_tmp39_ = gee_iterator_next (_tmp38_);
#line 114 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
			if (!_tmp39_) {
#line 114 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
				break;
#line 635 "default-contact.c"
			}
#line 114 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
			_tmp40_ = _i_it;
#line 114 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
			_tmp41_ = gee_iterator_get (_tmp40_);
#line 114 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
			i = (FolksIndividual*) _tmp41_;
#line 116 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
			_tmp42_ = i;
#line 116 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
			_vala_assert (_tmp42_ == NULL, "i == null");
#line 114 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
			_g_object_unref0 (i);
#line 649 "default-contact.c"
		}
#line 114 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
		_g_object_unref0 (_i_it);
#line 653 "default-contact.c"
	}
#line 82 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	_g_object_unref0 (removed);
#line 82 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	_g_object_unref0 (added);
#line 659 "default-contact.c"
}


static void default_contact_tests_class_init (DefaultContactTestsClass * klass) {
#line 26 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	default_contact_tests_parent_class = g_type_class_peek_parent (klass);
#line 26 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	g_type_class_add_private (klass, sizeof (DefaultContactTestsPrivate));
#line 26 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	G_OBJECT_CLASS (klass)->finalize = default_contact_tests_finalize;
#line 670 "default-contact.c"
}


static void default_contact_tests_instance_init (DefaultContactTests * self) {
#line 26 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	self->priv = DEFAULT_CONTACT_TESTS_GET_PRIVATE (self);
#line 677 "default-contact.c"
}


static void default_contact_tests_finalize (GObject* obj) {
	DefaultContactTests * self;
#line 26 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_DEFAULT_CONTACT_TESTS, DefaultContactTests);
#line 31 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 32 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	_g_free0 (self->priv->_fullname_persona);
#line 33 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	_g_object_unref0 (self->priv->_aggregator);
#line 26 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	G_OBJECT_CLASS (default_contact_tests_parent_class)->finalize (obj);
#line 693 "default-contact.c"
}


GType default_contact_tests_get_type (void) {
	static volatile gsize default_contact_tests_type_id__volatile = 0;
	if (g_once_init_enter (&default_contact_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (DefaultContactTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) default_contact_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (DefaultContactTests), 0, (GInstanceInitFunc) default_contact_tests_instance_init, NULL };
		GType default_contact_tests_type_id;
		default_contact_tests_type_id = g_type_register_static (TRACKER_TEST_TYPE_TEST_CASE, "DefaultContactTests", &g_define_type_info, 0);
		g_once_init_leave (&default_contact_tests_type_id__volatile, default_contact_tests_type_id);
	}
	return default_contact_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	DefaultContactTests* tests = NULL;
	DefaultContactTests* _tmp0_ = NULL;
#line 123 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	g_test_init (&args_length1, &args, NULL);
#line 125 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	_tmp0_ = default_contact_tests_new ();
#line 125 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	tests = _tmp0_;
#line 126 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	folks_test_case_register ((FolksTestCase*) tests);
#line 127 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	g_test_run ();
#line 128 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	folks_test_case_final_tear_down ((FolksTestCase*) tests);
#line 130 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	result = 0;
#line 130 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	_g_object_unref0 (tests);
#line 130 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	return result;
#line 731 "default-contact.c"
}


int main (int argc, char ** argv) {
#line 121 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	g_type_init ();
#line 121 "/home/treitter/collabora/folks/tests/tracker/default-contact.vala"
	return _vala_main (argv, argc);
#line 740 "default-contact.c"
}



